@font-face {
    font-family: 'Material Symbols Outlined';
    font-style: normal;
    font-weight: 400;
    src: url(material-symbols-outlined.woff2) format('woff2');
}

@font-face {
    font-display: swap;
    font-family: 'Open Sans';
    font-style: normal;
    font-weight: 400;
    src: url(open-sans-regular.woff2) format('woff2');
}

@font-face {
    font-display: swap;
    font-family: 'Open Sans';
    font-style: normal;
    font-weight: 500;
    src: url(open-sans-medium.woff2) format('woff2');
}

@font-face {
    font-display: swap;
    font-family: 'Open Sans';
    font-style: normal;
    font-weight: 700;
    src: url(open-sans-bold.woff2) format('woff2');
}

:root {
    --color-background-body: rgb(32, 33, 36);
    --color-background-neutral: rgba(31, 31, 31);
    --color-background-success: rgb(52, 168, 83);
    --color-background-failed: rgb(234, 67, 53);
    --color-background-error: rgb(251, 188, 4);
    --color-background-information: rgb(26, 115, 232);
    --color-title: rgb(232, 234, 237);
    --color-text: rgb(255, 255, 255);
    --color-subtle: rgb(154, 160, 166);
    --color-link: rgb(138, 180, 248);
}

* {
    box-sizing: inherit;
    color: var(--color-text);
    font-family: 'Open Sans', sans-serif;
    font-size: 1rem;
    line-height: 1.5rem;
}

body {margin: 0}
body, html {box-sizing: border-box; font-size: calc(15px + 0.390625vw)}
body, header {background-color: var(--color-background-body)}

header {
    align-items: center;
    background: linear-gradient(0deg, transparent 0, var(--color-background-body) 1rem);
    column-gap: 1rem;
    display: flex;
    height: 5.5rem;
    justify-content: space-between;
    left: 0;
    padding: 1rem;
    position: fixed;
    right: 0;
    top: 0;
}

main {padding: 6.5rem 1rem 1rem}
section {padding-bottom: 2rem}
h1 {color: var(--color-title); font-size: 2rem; font-weight: 700}
h2 {color: var(--color-title); font-size: 1.5rem; font-weight: 500}
a, a:visited, a:hover, a:active {color: var(--color-link); text-decoration: none}
form {display: flex; flex-flow: column wrap; margin: 0 auto; max-width: 30rem}
form input, form select {flex: 1}

select, input[type=text], input[type=url], input[type=number] {
    background: rgb(60, 64, 67);
    border: 2px solid transparent;
    border-radius: 0.36rem;
    caret-color: var(--color-link);
    color: rgba(255, 255, 255, 0.87);
    padding: 0.5rem 0.75rem;
}

select:focus, input[type=text]:focus, input[type=url]:focus, input[type=number]:focus {
    border-color: rgb(138, 180, 248);
    outline: none; 
}

input[type=submit] {
    background: rgba(120, 217, 236, 0.4);
    border: 0;
    border-radius: 0.36rem;
    color: rgb(218, 220, 224);
    font-weight: 500;
    padding: 0.5rem 0.75rem;
}

input[type=search] {
    background: rgba(255, 255, 255, 0.0);
    border: 0;
    caret-color: var(--color-link);
    color: rgba(255, 255, 255, 0.87);
    margin: 0;
    padding: 0;
}

input[type=search]:focus {
    color: var(--color-link);
    outline: none;
}

table {border-collapse: collapse; width: 100%}
td, th {border:0; margin:0; text-align:left}
tr {border-bottom: 1px solid rgba(255, 255, 255, 0.12)}
td {padding: 8px 7px 8px 8px; vertical-align: top}

[dir=rtl] td, [dir=rtl] th {text-align: right}

th {
    background: linear-gradient(0deg,rgba(105,145,214,0.08),rgba(105,145,214,0.08));
    font-weight: 500;
    height: 3rem;
    padding: 0.5rem;
    vertical-align: middle;
}

.material-symbols {
    color: inherit;
    font-family: 'Material Symbols Outlined';
    font-variation-settings: 'FILL' 1, 'wght' 400, 'GRAD' 0, 'opsz' 24;
    font-weight: normal;
    font-style: normal;
    font-size: inherit;
    line-height: inherit;
    vertical-align: bottom;
    display: inline-block;
    text-transform: none;
    letter-spacing: normal;
    word-wrap: normal;
    white-space: nowrap;
    direction: ltr;
}

.filter-search {
    background: linear-gradient(0deg,rgba(105,145,214,0.08),rgba(105,145,214,0.08));
    border-radius: 2rem;
    color: var(--color-background-body);
    flex: 1;
    padding: 0.5rem 0.75rem;
}

.filter-search input {width: 100%}
.container {display: flex; flex-flow: column wrap; row-gap: 0.25rem}
.item {flex: 1}

.flash {
    align-items: center;
    animation: hideAnimation 0s ease-in 3s;
    animation-fill-mode: forwards;
    background: linear-gradient(0deg,rgba(209,225,255,0.08),rgba(209,225,255,.08)),#1f1f1f;
    bottom: 0;
    display: flex;
    font-size: 2rem;
    justify-content: center;
    left: 0;
    line-height: 3rem;
    position: fixed;
    right: 0;
    text-align: center;
    top: 0;
    z-index: 99;
}

.success {background-color: var(--color-background-success)}
.failed {background-color: var(--color-background-failed)}
.error {background-color: var(--color-background-error)}
.information {background-color: var(--color-background-information)}

@keyframes hideAnimation {
    to {
        visibility: hidden;
        width: 0;
        height: 0;
    }
}

a.outline {
    border: 1px solid var(--color-link);
    border-radius: 1rem;
    color: var(--color-link);
    display: flex;
    line-height: 1rem;
    padding: 0.25rem 0.5rem;
}

a.outline:hover {
    background: rgba(138,180,248,.04);
}

a.action-icon {
    align-items: center;
    border-radius: 50%;
    color: var(--color-subtle);
    display: flex;
    height: 2.5rem;
    justify-content: center;
    line-height: 1rem;
    vertical-align: middle;
    width: 2.5rem;
}

a.action-icon:hover {
    background: rgba(232,234,237,.04);
    color: #e8eaed;
}

#scroll-top {
    align-items: center;
    background: rgb(60, 64, 67);
    bottom: 1.5rem;
    border: 0;
    border-radius: 50%;
    color: rgb(95, 99, 104);
    cursor: pointer;
    display: none;
    font-size: 1.75rem;
    height: 4rem;
    justify-content: center;
    position: fixed;
    right: 1.75rem;
    width: 4rem;
    vertical-align: middle;
    z-index: 98;
}
