{% extends 'base.htm' %}
{% block title %}Page Not Found{% endblock %}
{% block nav %}
{% endblock %}
{% block main %}
<div class="container" style="justify-content: center">
    <h2>Page Not Found</h2>
    <p>
        What you were looking for is just not there. 
        <a href="{{ url_for('home.index') }}">Go somewhere nice.</a>
    </p>
</div>
{% endblock %}
