{% extends 'base.htm' %}
{% block title %}Create State{% endblock %}
{% block header %}
{% endblock %}
{% block main %}
<form method="post">
    <h2>Create State</h2>
    <label for="title">Title</label>
    <input name="title" type="text" required><br>
    <input type="submit" value="Create">
</form>
{% endblock %}
